@@ -641,4 +641,10 @@ void Fl_add_system_handler(int (*cb)(void *, void *), void *data) {
 
 void Fl_remove_system_handler(int (*cb)(void *, void *)) {
     Fl::remove_system_handler(cb);
-}
\ No newline at end of file
+}
+
+#ifdef CFLTK_USE_GL
+int Fl_gl_visual(int mode) {
+    return Fl::gl_visual(mode);
+}
+#endif
\ No newline at end of file
